==> wikitty-api-3.0.2-sources.jar: org/nuiton/wikitty/entities/WikittyTreeNodeImpl.java <==
/*
 * #%L
 * Wikitty :: api
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.wikitty.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;


public  class WikittyTreeNodeImpl extends WikittyTreeNodeAbstract {

    private static final long serialVersionUID = -5516570942284743676L;
    /**
     * WikittyTreeNodeImpl :
     */

    public WikittyTreeNodeImpl() {
        super();
}

    /**
     * WikittyTreeNodeImpl :
     * @param wikitty 
     */

    public WikittyTreeNodeImpl(Wikitty wikitty) {
        super(wikitty);
}

    /**
     * WikittyTreeNodeImpl :
     * @param businessEntityImpl 
     */

    public WikittyTreeNodeImpl(BusinessEntityImpl businessEntityImpl) {
        super(businessEntityImpl.getWikitty());
}


} //WikittyTreeNodeImpl

==> wikitty-api-3.0.3-sources.jar: org/nuiton/wikitty/entities/WikittyTreeNodeImpl.java <==
/*
 * #%L
 * Wikitty :: api
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package org.nuiton.wikitty.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;


public  class WikittyTreeNodeImpl extends WikittyTreeNodeAbstract {

    private static final long serialVersionUID = 1380998618085132861L;
    /**
     * WikittyTreeNodeImpl :
     */

    public WikittyTreeNodeImpl() {
        super();
}

    /**
     * WikittyTreeNodeImpl :
     * @param wikitty 
     */

    public WikittyTreeNodeImpl(Wikitty wikitty) {
        super(wikitty);
}

    /**
     * WikittyTreeNodeImpl :
     * @param businessEntityImpl 
     */

    public WikittyTreeNodeImpl(BusinessEntityImpl businessEntityImpl) {
        super(businessEntityImpl.getWikitty());
}


} //WikittyTreeNodeImpl
